# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/node_pool.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/node_pool.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfc\x05\n\x08NodePool\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1b\n\x0emin_node_count\x18\n \x01(\x05\x42\x03\xe0\x41\x01\x12\x1b\n\x0emax_node_count\x18\x0b \x01(\x05\x42\x03\xe0\x41\x01\x12%\n\x18overprovision_node_count\x18\x0c \x01(\x05\x42\x03\xe0\x41\x01\x12-\n\rgke_node_pool\x18\x02 \x01(\x0b\x32\x14.gateway.GkeNodePoolH\x00\x12-\n\reks_node_pool\x18\x07 \x01(\x0b\x32\x14.gateway.EksNodePoolH\x00\x12/\n\x0e\x66\x61ke_node_pool\x18\x03 \x01(\x0b\x32\x15.gateway.FakeNodePoolH\x00\x12\x37\n\x12minikube_node_pool\x18\x04 \x01(\x0b\x32\x19.gateway.MinikubeNodePoolH\x00\x12<\n\x0b\x61nnotations\x18\x0e \x03(\x0b\x32\".gateway.NodePool.AnnotationsEntryB\x03\xe0\x41\x01\x12.\n\x05state\x18\x05 \x01(\x0e\x32\x17.gateway.NodePool.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12-\n\x05stats\x18\r \x01(\x0b\x32\x16.gateway.NodePoolStatsB\x06\xe0\x41\x03\xe0\x41\x05\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x10\n\x0enode_pool_type\"\xdd\x01\n\x0bGkeNodePool\x12\x1c\n\x0cmachine_type\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12 \n\x10\x61\x63\x63\x65lerator_type\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11\x61\x63\x63\x65lerator_count\x18\x05 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04spot\x18\x06 \x01(\x08\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fservice_account\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04zone\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1e\n\x0enode_pool_name\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"\xf2\x01\n\x0b\x45ksNodePool\x12\x19\n\tnode_role\x18\x01 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rinstance_type\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x14\n\x04spot\x18\x04 \x01(\x08\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fnode_group_name\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1a\n\nsubnet_ids\x18\x06 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04zone\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fplacement_group\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0flaunch_template\x18\t \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"P\n\x0c\x46\x61keNodePool\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\x12\x11\n\tnum_nodes\x18\x02 \x01(\x05\x12\x17\n\x0fservice_account\x18\x03 \x01(\t\"\x12\n\x10MinikubeNodePool\"\xe5\x02\n\rNodePoolStats\x12\x12\n\nnode_count\x18\x01 \x01(\x05\x12\x16\n\x0eranks_per_node\x18\x02 \x01(\x05\x12\x19\n\x11\x65nvironment_count\x18\x03 \x01(\x05\x12\x19\n\x11\x65nvironment_ranks\x18\x04 \x01(\x05\x12\x42\n\x0f\x62\x61tch_job_count\x18\x05 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobCountEntry\x12\x42\n\x0f\x62\x61tch_job_ranks\x18\x06 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobRanksEntry\x1a\x34\n\x12\x42\x61tchJobCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x34\n\x12\x42\x61tchJobRanksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"r\n\x15\x43reateNodePoolRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12)\n\tnode_pool\x18\x02 \x01(\x0b\x32\x11.gateway.NodePoolB\x03\xe0\x41\x02\x12\x19\n\x0cnode_pool_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\'\n\x12GetNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"-\n\x18ReconcileNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListNodePoolsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"k\n\x15ListNodePoolsResponse\x12%\n\nnode_pools\x18\x01 \x03(\x0b\x32\x11.gateway.NodePool\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"B\n\x15UpdateNodePoolRequest\x12)\n\tnode_pool\x18\x01 \x01(\x0b\x32\x11.gateway.NodePoolB\x03\xe0\x41\x02\"*\n\x15\x44\x65leteNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"F\n\x1b\x42\x61tchDeleteNodePoolsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\",\n\x17GetNodePoolStatsRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.node_pool_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _NODEPOOL_ANNOTATIONSENTRY._options = None
  _NODEPOOL_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _NODEPOOL.fields_by_name['name']._options = None
  _NODEPOOL.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _NODEPOOL.fields_by_name['display_name']._options = None
  _NODEPOOL.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _NODEPOOL.fields_by_name['create_time']._options = None
  _NODEPOOL.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _NODEPOOL.fields_by_name['min_node_count']._options = None
  _NODEPOOL.fields_by_name['min_node_count']._serialized_options = b'\340A\001'
  _NODEPOOL.fields_by_name['max_node_count']._options = None
  _NODEPOOL.fields_by_name['max_node_count']._serialized_options = b'\340A\001'
  _NODEPOOL.fields_by_name['overprovision_node_count']._options = None
  _NODEPOOL.fields_by_name['overprovision_node_count']._serialized_options = b'\340A\001'
  _NODEPOOL.fields_by_name['annotations']._options = None
  _NODEPOOL.fields_by_name['annotations']._serialized_options = b'\340A\001'
  _NODEPOOL.fields_by_name['state']._options = None
  _NODEPOOL.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _NODEPOOL.fields_by_name['status']._options = None
  _NODEPOOL.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _NODEPOOL.fields_by_name['stats']._options = None
  _NODEPOOL.fields_by_name['stats']._serialized_options = b'\340A\003\340A\005'
  _GKENODEPOOL.fields_by_name['machine_type']._options = None
  _GKENODEPOOL.fields_by_name['machine_type']._serialized_options = b'\340A\002\340A\005'
  _GKENODEPOOL.fields_by_name['accelerator_type']._options = None
  _GKENODEPOOL.fields_by_name['accelerator_type']._serialized_options = b'\340A\001\340A\005'
  _GKENODEPOOL.fields_by_name['accelerator_count']._options = None
  _GKENODEPOOL.fields_by_name['accelerator_count']._serialized_options = b'\340A\001\340A\005'
  _GKENODEPOOL.fields_by_name['spot']._options = None
  _GKENODEPOOL.fields_by_name['spot']._serialized_options = b'\340A\001\340A\005'
  _GKENODEPOOL.fields_by_name['service_account']._options = None
  _GKENODEPOOL.fields_by_name['service_account']._serialized_options = b'\340A\001\340A\005'
  _GKENODEPOOL.fields_by_name['zone']._options = None
  _GKENODEPOOL.fields_by_name['zone']._serialized_options = b'\340A\001\340A\005'
  _GKENODEPOOL.fields_by_name['node_pool_name']._options = None
  _GKENODEPOOL.fields_by_name['node_pool_name']._serialized_options = b'\340A\001\340A\005'
  _EKSNODEPOOL.fields_by_name['node_role']._options = None
  _EKSNODEPOOL.fields_by_name['node_role']._serialized_options = b'\340A\001\340A\005'
  _EKSNODEPOOL.fields_by_name['instance_type']._options = None
  _EKSNODEPOOL.fields_by_name['instance_type']._serialized_options = b'\340A\002\340A\005'
  _EKSNODEPOOL.fields_by_name['spot']._options = None
  _EKSNODEPOOL.fields_by_name['spot']._serialized_options = b'\340A\001\340A\005'
  _EKSNODEPOOL.fields_by_name['node_group_name']._options = None
  _EKSNODEPOOL.fields_by_name['node_group_name']._serialized_options = b'\340A\001\340A\005'
  _EKSNODEPOOL.fields_by_name['subnet_ids']._options = None
  _EKSNODEPOOL.fields_by_name['subnet_ids']._serialized_options = b'\340A\001\340A\005'
  _EKSNODEPOOL.fields_by_name['zone']._options = None
  _EKSNODEPOOL.fields_by_name['zone']._serialized_options = b'\340A\001\340A\005'
  _EKSNODEPOOL.fields_by_name['placement_group']._options = None
  _EKSNODEPOOL.fields_by_name['placement_group']._serialized_options = b'\340A\001\340A\005'
  _EKSNODEPOOL.fields_by_name['launch_template']._options = None
  _EKSNODEPOOL.fields_by_name['launch_template']._serialized_options = b'\340A\001\340A\005'
  _NODEPOOLSTATS_BATCHJOBCOUNTENTRY._options = None
  _NODEPOOLSTATS_BATCHJOBCOUNTENTRY._serialized_options = b'8\001'
  _NODEPOOLSTATS_BATCHJOBRANKSENTRY._options = None
  _NODEPOOLSTATS_BATCHJOBRANKSENTRY._serialized_options = b'8\001'
  _CREATENODEPOOLREQUEST.fields_by_name['parent']._options = None
  _CREATENODEPOOLREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATENODEPOOLREQUEST.fields_by_name['node_pool']._options = None
  _CREATENODEPOOLREQUEST.fields_by_name['node_pool']._serialized_options = b'\340A\002'
  _CREATENODEPOOLREQUEST.fields_by_name['node_pool_id']._options = None
  _CREATENODEPOOLREQUEST.fields_by_name['node_pool_id']._serialized_options = b'\340A\002'
  _GETNODEPOOLREQUEST.fields_by_name['name']._options = None
  _GETNODEPOOLREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _RECONCILENODEPOOLREQUEST.fields_by_name['name']._options = None
  _RECONCILENODEPOOLREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTNODEPOOLSREQUEST.fields_by_name['parent']._options = None
  _LISTNODEPOOLSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTNODEPOOLSREQUEST.fields_by_name['page_size']._options = None
  _LISTNODEPOOLSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNODEPOOLSREQUEST.fields_by_name['page_token']._options = None
  _LISTNODEPOOLSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNODEPOOLSREQUEST.fields_by_name['filter']._options = None
  _LISTNODEPOOLSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTNODEPOOLSREQUEST.fields_by_name['order_by']._options = None
  _LISTNODEPOOLSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATENODEPOOLREQUEST.fields_by_name['node_pool']._options = None
  _UPDATENODEPOOLREQUEST.fields_by_name['node_pool']._serialized_options = b'\340A\002'
  _DELETENODEPOOLREQUEST.fields_by_name['name']._options = None
  _DELETENODEPOOLREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _BATCHDELETENODEPOOLSREQUEST.fields_by_name['parent']._options = None
  _BATCHDELETENODEPOOLSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _BATCHDELETENODEPOOLSREQUEST.fields_by_name['names']._options = None
  _BATCHDELETENODEPOOLSREQUEST.fields_by_name['names']._serialized_options = b'\340A\002'
  _GETNODEPOOLSTATSREQUEST.fields_by_name['name']._options = None
  _GETNODEPOOLSTATSREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _NODEPOOL._serialized_start=125
  _NODEPOOL._serialized_end=889
  _NODEPOOL_ANNOTATIONSENTRY._serialized_start=738
  _NODEPOOL_ANNOTATIONSENTRY._serialized_end=788
  _NODEPOOL_STATE._serialized_start=790
  _NODEPOOL_STATE._serialized_end=871
  _GKENODEPOOL._serialized_start=892
  _GKENODEPOOL._serialized_end=1113
  _EKSNODEPOOL._serialized_start=1116
  _EKSNODEPOOL._serialized_end=1358
  _FAKENODEPOOL._serialized_start=1360
  _FAKENODEPOOL._serialized_end=1440
  _MINIKUBENODEPOOL._serialized_start=1442
  _MINIKUBENODEPOOL._serialized_end=1460
  _NODEPOOLSTATS._serialized_start=1463
  _NODEPOOLSTATS._serialized_end=1820
  _NODEPOOLSTATS_BATCHJOBCOUNTENTRY._serialized_start=1714
  _NODEPOOLSTATS_BATCHJOBCOUNTENTRY._serialized_end=1766
  _NODEPOOLSTATS_BATCHJOBRANKSENTRY._serialized_start=1768
  _NODEPOOLSTATS_BATCHJOBRANKSENTRY._serialized_end=1820
  _CREATENODEPOOLREQUEST._serialized_start=1822
  _CREATENODEPOOLREQUEST._serialized_end=1936
  _GETNODEPOOLREQUEST._serialized_start=1938
  _GETNODEPOOLREQUEST._serialized_end=1977
  _RECONCILENODEPOOLREQUEST._serialized_start=1979
  _RECONCILENODEPOOLREQUEST._serialized_end=2024
  _LISTNODEPOOLSREQUEST._serialized_start=2027
  _LISTNODEPOOLSREQUEST._serialized_end=2163
  _LISTNODEPOOLSRESPONSE._serialized_start=2165
  _LISTNODEPOOLSRESPONSE._serialized_end=2272
  _UPDATENODEPOOLREQUEST._serialized_start=2274
  _UPDATENODEPOOLREQUEST._serialized_end=2340
  _DELETENODEPOOLREQUEST._serialized_start=2342
  _DELETENODEPOOLREQUEST._serialized_end=2384
  _BATCHDELETENODEPOOLSREQUEST._serialized_start=2386
  _BATCHDELETENODEPOOLSREQUEST._serialized_end=2456
  _GETNODEPOOLSTATSREQUEST._serialized_start=2458
  _GETNODEPOOLSTATSREQUEST._serialized_end=2502
# @@protoc_insertion_point(module_scope)



class FireworksError(Exception):
    pass


class PermissionError(FireworksError):
    """A permission denied error."""

    pass


class InvalidRequestError(FireworksError):
    """A invalid request error."""

    pass


class AuthenticationError(FireworksError):
    """A authentication error."""

    pass


class RateLimitError(FireworksError):
    """A rate limit error."""

    pass


class InternalServerError(FireworksError):
    """An internal server error."""

    pass


class ServiceUnavailableError(FireworksError):
    """A service unavailable error."""

    pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/sign_in.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/sign_in.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\"\x8f\x01\n\rSignInRequest\x12\x41\n\x0eoauth_provider\x18\x01 \x01(\x0e\x32$.gateway.SignInRequest.OAuthProviderB\x03\xe0\x41\x02\";\n\rOAuthProvider\x12\x1e\n\x1aOAUTH_PROVIDER_UNSPECIFIED\x10\x00\x12\n\n\x06GOOGLE\x10\x01\"3\n\x18GetOAuthArgumentsRequest\x12\x17\n\naccount_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"B\n\x19GetOAuthArgumentsResponse\x12\x12\n\nissuer_url\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\tB\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.sign_in_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _SIGNINREQUEST.fields_by_name['oauth_provider']._options = None
  _SIGNINREQUEST.fields_by_name['oauth_provider']._serialized_options = b'\340A\002'
  _GETOAUTHARGUMENTSREQUEST.fields_by_name['account_id']._options = None
  _GETOAUTHARGUMENTSREQUEST.fields_by_name['account_id']._serialized_options = b'\340A\002'
  _SIGNINREQUEST._serialized_start=68
  _SIGNINREQUEST._serialized_end=211
  _SIGNINREQUEST_OAUTHPROVIDER._serialized_start=152
  _SIGNINREQUEST_OAUTHPROVIDER._serialized_end=211
  _GETOAUTHARGUMENTSREQUEST._serialized_start=213
  _GETOAUTHARGUMENTSREQUEST._serialized_end=264
  _GETOAUTHARGUMENTSRESPONSE._serialized_start=266
  _GETOAUTHARGUMENTSRESPONSE._serialized_end=332
# @@protoc_insertion_point(module_scope)
